@@ -25,9 +25,9 @@ sub new
 {   my ($class,$file,$findlength)=@_;
     my $self=bless {}, $class;
     local $_;
-    # check that the file exists and is readable
-    unless ( -e $file && -r $file )
-    {	warn "File '$file' does not exist or cannot be read.\n";
+    # check that the file exists
+    unless (-e $file)
+    {	warn "File '$file' does not exist.\n";
 	return undef;
     }
     $self->{filename} = $file;
@@ -72,7 +72,7 @@ sub _ReadHeader
 		frames		=> $nbframes,
 		rate		=> $freq,
 		seconds		=> $seconds,
-		bitrate		=> $bitrate,
+		bitrate_calculated=> $bitrate,
 		compression	=> $compression{$compression} || $compression,
 	);
 	#warn "$_=$info{$_}\n" for keys %info;
